@@ -1021,12 +1021,10 @@ int netcfg_get_hostname(struct debconfclient *client, char *template, char *host
 
         debconf_get(client, template);
 
-        strncpy(hostname, client->value, MAXHOSTNAMELEN);
-
-        if (!valid_domain(hostname)) {
-            di_info("%s is an invalid domain", hostname);
+        if (!valid_domain(client->value)) {
+            di_info("%s is an invalid domain", client->value);
             debconf_subst(client, "netcfg/invalid_hostname",
-                          "hostname", hostname);
+                          "hostname", client->value);
             snprintf(buf, sizeof(buf), "%i", MAXHOSTNAMELEN);
             debconf_subst(client, "netcfg/invalid_hostname",
                       "maxhostnamelen", buf);
@@ -1037,6 +1035,8 @@ int netcfg_get_hostname(struct debconfclient *client, char *template, char *host
             continue;
         }
 
+        strncpy(hostname, client->value, MAXHOSTNAMELEN);
+
         if (accept_domain && (s = strchr(hostname, '.'))) {
             di_info("Detected we have an FQDN; splitting and setting domain");
             if (s[1] == '\0') { /* "somehostname." <- . should be ignored */
